@@ -5,9 +5,7 @@ test_that('measures',
 	d<-c(0,rep(sqrt(2),6))
 	t<-c(rep(1, 6), 3)
 	expect_equal(distance(x),d)
-	expect_equal(distanceSummary(x)$AverDist,mean(d))
 	expect_equal(speed(x),d/t)
-	expect_equal(speedSummary(x)$AverSpeed, mean(d/t))
 	expect_equal(timeLag(x), t)
 	expect_equal(timeLag(x, 'secs'), t)
 	expect_equal(timeLag(x, 'mins'), t/60)
@@ -22,4 +20,4 @@ test_that('measures',
 	expect_equal(speed(xx),dd/t)
 	expect_equal(length(turnAngleGc(xx)), n.locs(xx)-2)
 }
-)
\ No newline at end of file
+)
